#
# spec file for package kvpnc
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           kvpnc
Version:        0.9.6a
Release:        16.3
Summary:        GUI Front-End for various VPN clients
License:        GPL-2.0+
Group:          Productivity/Networking/System
Url:            http://home.gna.org/kvpnc/
Source0:        http://download.gna.org/kvpnc/%{name}-%{version}-kde4.tar.bz2
Source1:        http://download.gna.org/kvpnc/%{name}-0.9.6-kde4-locale.tar.bz2
Patch0:         kvpnc-gcc47.patch
Patch1:         upstream-fixes.patch
Patch2:         kvpnc-gcc6.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# only needed to patch broken images in the upstream tarball
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  libgcrypt-devel
BuildRequires:  libkde4-devel
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
%kde4_runtime_requires
Recommends:     ksshaskpass
Recommends:     opensc
Recommends:     openssl
Provides:       kde4-kvpnc = %{version}
Obsoletes:      kde4-kvpnc < %{version}

%description
The application can create configurations for various kinds of VPN connections.
You should also install a vpn package (e.g. openvpn, strongswan, vpnc).

%prep
%setup -q -n %{name}-%{version}-kde4 -a1
%patch0 -p1
%patch1 -p0
%patch2 -p1
echo "find_package(Msgfmt REQUIRED)" >> CMakeLists.txt
echo "find_package(Gettext REQUIRED)" >> CMakeLists.txt
echo "add_subdirectory( po )" >> CMakeLists.txt

# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/main.cpp
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/main.cpp
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/kvpncconfig.cpp

# This image looks corrupt?
rm $RPM_BUILD_DIR/%{name}-%{version}-kde4/src/icons/actions/lo22-action-connecting.png
# Patch image with wrong dimensions - Fixes rpmlint warning "wrong-icon-size"
for d in src/icons src/icons/actions; do
  pushd "$d"
  for s in 16 22 32 48 64; do
    ls *"$s"-*.png || break
    for f in *"$s"-*.png *"$s"-*.png *"$s"-*.png *"$s"-*.png; do
      geom=$(identify -ping "$f"|cut -f3 -d" ")
      x=${geom%x*}
      y=${geom#*x}
      if [ "$x" != "$s" -o "$y" != "$s" ]; then
        if [ "$x" -gt "$y" ]; then
          nugeom="${x}x${x}"
          grav=south
        elif [ "$x" -lt "$y" ]; then
          nugeom="${y}x${y}"
          grav=center
        else
          nugeom=""
        fi
        [ -n "$nugeom" ] && mogrify -strip -extent "$nugeom" -background transparent -gravity "$grav" "$f"
        mogrify -strip -scale "$s"x"$s" -background transparent "$f"
      fi
    done
  done
  popd
done

%build
%cmake_kde4 -d build
%make_jobs

%install
cd build
%kde4_makeinstall
cd ..

# Fix permissions
chmod 755 %{buildroot}%{_kde4_appsdir}/kvpnc/ping_check.sh

%if 0%{?suse_version}
%suse_update_desktop_file -G "VPNC FrontEnd" kvpnc Qt KDE Network RemoteAccess
%endif

# Remove unneeded locales
%if 0%{?suse_version} && 0%{?suse_version} < 1140
rm -rf %{buildroot}%{_datadir}/locale/hne/
rm -rf %{buildroot}%{_datadir}/locale/x-test/
%endif

%fdupes -s %{buildroot}%{_datadir}

%find_lang %{name}

%clean
rm -rf %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog README TODO
%{_kde4_bindir}/kvpnc
%{_kde4_applicationsdir}/kvpnc.desktop
%{_kde4_iconsdir}/*/*/*/*
%{_kde4_appsdir}/kvpnc/

%changelog
* Fri Jun 17 2016 tittiatcoke@gmail.com
- Cherry pick important commits from upstream (also fixes GCC6 build)
  * upstream-fixes.patch
  * kvpnc-gcc6.patch (boo#985190)
* Tue Mar  8 2016 bwiedemann@suse.com
- Strip png timestamps to fix build-compare
* Sat Apr 20 2013 hrvoje.senjan@gmail.com
- Remove lo22-action-connecting.png image as it is corrupt
* Wed Mar 21 2012 dimstar@opensuse.org
- Add kvpnc-gcc47.patch: Fix build with gcc 4.7.
* Wed May 25 2011 asterios.dramis@gmail.com
- update to version 0.9.6a
  * ping_check.sh install fixed.
- Spec files updates:
  * Changes based on spec-cleaner run.
  * Removed gpgme-devel, kdebase4-workspace-devel, libkdepimlibs4-devel and
    libqimageblitz-devel from BuildRequires (not needed) and added
    libgcrypt-devel.
  * Added some Recommended packages.
  * Updates in Summary: and %%description entries.
  * Minor other updates.
- Fixed rpmlint warnings "file-contains-date-and-time", "wrong-icon-size",
  "non-executable-script" and "invalid-lc-messages-dir".
- Removed kvpnc.rpmlintrc.
* Tue Mar  9 2010 tittiatcoke@gmail.com
- update to version 0.9.6
  This release fixes a critical bug in KDE4 version and some other bugs.
  * bugfixes:
  - if no profile was imported at kvpnc profile import keep profile
    name at profile selector fixed
  - remote id toggle at newprofilewizard at *swan use fixed
  - remote id options at newprofilewizard at *swan use fixed
  - local id options at newprofilewizard at *swan use fixed
  - split specific options at preferencesdialog in multiple tabs
    (*swan, racoon, pptp, openvpn) for reducing preferencesdialog size
    (bko#219556)
  - vpnc config options if ca cert or ca dir empty for use hybrid mode fixed
    (thanks to Todd Kennedy)
  - enable psk options at hybrid mode fixed (vpnc)
  - selecting profile selects not right profile fixed
  - openvpn specific options toggle fixed
  - crash at p12 certificate import fixed
  - p12 import at openvpn profile import fixed
  - crash at generate openvpn key fixed (bko#224507)
  - remote network netmask at newprofilewizard at *swan use fixed
  - use udp label text at newprofilewizard at *swan use fixed
  * features:
  - check if profile already exists at kvpnc profile import added
  - toggle all/none profiles at kvpnc profile import added
  - user defined import prefix at kvpnc profile import added
  - kde4 translation updated
* Wed Mar  3 2010 tittiatcoke@gmail.com
- update to version 0.9.5
  * bugfixes:
  - use nat fixed (vpnc)
  - vpnc config option for use hybrid mode fixed
  - hide useless cisco cert comboboxes if not needed
  - use nat at pcf import fixed
  - cancel at pcf import if profile name already exists fixed
  - parameter at log message fixed (openvpn)
  - bool options fixed at kvpnc profile import
  - wrong label (before disconnect) in preferencesdialog fixed
  - HTTP Proxy Authtype at kvpnc profile export fixed
  - auth type at kvpnc profile export fixed
  - hide ipsec virtual ip options at newprofilewizard (openvpn)
  - crash at connecting fixed (openvpn)
  - keeping existing nameserver fixed (openvpn)
  - memleak fix (vpnc)
  - vpnc start fix [kde4]
  - some vpnc kill fixes
  - fixes regarding indexes of comboboxes in preferencesdialog
  - displaying auth type at change in preferencesdialog
  - authtype display at profile change fixed
  - display add/remove additional network routes fixed
  - use default interface at add/remove additional network routes
    if no device is given
  - hybrid mode at preferencesdialog fixed (vpnc)
  - save CertPath at preferencesdialog fixed (racoon)
  - if profile name with spaces is entered at newprofilewizard
    dont continue fixed
  - use nat preselection at newprofilewizard fixed
  - udp port toggle at newprofilewizard fixed
  - default route combobox at newprofilewizard fixed [kde4]
  - index fixes at newprofilewizard [kde4]
  - crash at connecting state fixed (openvpn)
  - save username if username/password from authdialog is
    requested save is checked (openvpn)
  - dont display authdialog if userdata already collected (openvpn)
  - memleak fix (openvpn)
  - crash at newprofilewizard at ssh type on tunnel type change fixed
  * features:
  - use cisco icon instead pcf icon in for pcf menu entry
  - kde4 translation updated
* Tue Mar  2 2010 tittiatcoke@gmail.com
- update to version 0.9.4
  * bugfixes
  * features
    + save only new profiles at ipsec config file import
    + ipsec error handling improved
    + support for inline certificates (user certificate, ca certificate,
    private key, tls-key) at openvpn config file import added
    + importing username by special line at openvpn config file import added
    + hide ipsec related settings at virtualip options page if not nessary
    + cpu usage reduced
    + dock tooltip better formatted
    + eventsrc updated
    + stop connecting if hostname could not resolved at racoon profile
    + displaying virtual ip address in tooltip added (*swan, racoon)
    + dhgroup for esp added (*swan)
    + filter for fritzbox vpn user config file changed to "vpnuser_*.cfg"
    + dont use "VPN connexion established" as successful connect at racoon
    + useless netmask removed at setkey rules
    + temporary static rightid removed at *swan
    + useless http proxy options on racoon usage disabled
    + user options on racoon usage disabled if not xauth or l2tp
    + dottedIpv4Netmask2NetmaskBytes function at utils added
    + fritzbox vpn user config file import added
    + set text instead item number for auth type at preferencesdialog
    + save single profile at additionally to config sync
    + racoon virtual ip support added (use LeftSourceIP)
    + debug options for pluto and klips added (*swan)
    + remote id moved from cert options to ipsec/racoon options
    + checking gre support at pptp added
    + load ip_gre module if nessary at pptp
    + code cleanup
    + display profile info in profile selector tooltip added
    + not useable mppe and ppp options now disabled at l2tpd profile
    + l2tp auth at profile selector tooltip for l2tp profiles added
    + save only current profile instead of all if passwords got from
    dialog during connecting
    + messagebox for user added if connection was refused at pptp connect try
    + use KProcess instead QProcess in some cases at utils
    + tun device check more reliable made
    + allow hostname instead of ip address in ping check too
    + ciscouserca type at importcertifcate dialog added (user + ca certificate)
    + certificate will now imported into cisco cert store if set in config file
    + use cisco cert store option at certificate settings at orig cisco usage added
    + importing a pcf file containing certificate will now import the certificate
    too (file/cert store is selected by CertStore option in pcf file)
    + certificate select dialog now show also certs with der extension
    + hybrid support detection at vpnc added (openssl support compiled in)
    + hybrid mode (ca cert and name/password) added (vpnc, vpnclient)
    + ca certificate import at importcertifcate dialog added
    + use nat option added (split use udp into use udp and use nat for more
    flexibility)
    + process only events if needed at getting certs from Cisco cert store
    + debug output for replacing defaultroute added (vpnc)
    + display other informal msg from ipsec helper too [kde4]
    + read only first ip address from interface at getInterfaceIP [kde4]
    + clear text password from config file removed (workaround found) [kde4]
    + add userpage at pcf import on new profilewizward disabled [kde4]
    + set default network protocol to tcp at openvpn profile import
    + use file select dialog instead of textinput dialog for getting filename at
    openvpn config file export
    + id type tooltips at remote/local id comboboxes added
    + netstat toolinfo display added
    + certificate prefix can now specified at openvpn type
* Mon Feb 15 2010 llunak@novell.com
- fix build with gcc-4.5
* Thu Sep  3 2009 tittiatcoke@gmail.com
- update to version 0.9.3
  * bugfixes
  - --non-inter option removed because no longer nessary
  - useless extra route disabled
  - resolvconf fixes
  - creating additional route with /32 mask fixed
  - crash on wrong import password on p12 certificate fixed
  - certificate import p12 fixed
  - keeping default route fixed (pptp)
  - crash at import ipsec config fixed (#205502) [kde4]
  - displaying values in importprofiledialog after importing ipsec config fixed
  - enterxauthinteractivepasscode layout fixed
  - ppp auth method in preferencesdialog fixed
  - ask username/password only if needed fixed (pptp)
  - cisco nat mode saving fixed
  - dialog change detection in preferencesdialog fixed
  - ProfileCmdExecAfterDisconnectSelector on preferencesdialog fixed
  - ProfileSpecificSelector on preferencesdialog fixed
  - icon size on daemon options fixed
  - icon size on helper program options fixed
  - export kvpnc profiles fixed
  - filename select on kvpnc profile import fixed
  * Features
  - check cisco_cert_mgt tool before running the wizard added
  - allow empty certificate password on vpnclient
  - qt3 compat usage removed in kfeedbackdialog
  - import/export profiles now checkable (instead of select)
* Sat Aug  1 2009 tittiatcoke@gmail.com
- update to version 0.9.2
  * features
  - ask user password on each connect option added
  - $HOME/bin now in search path of default paths
  - default paths search order changed
  - useless comment on tail info removed
  - DNS_UPDATE option renamed to Update DNS configuration,
    if not checked, /etc/resolv.conf will not changed
  - ping_check.sh now useable with ash
  - ping_check.sh device parameter added
  - connection status check now uses tunnel device
  - translation update
  - empty patch checking on load/save added
  - detecting pkcs11 ids for openvpn via openvpn added
  - option for selecting open profilemanger after import added
  - pkcs11 parameters changed for openvpn >= 2.1rc-9
  - openvpn version detection improved
  - pkcs11 token support for other than etoken added
  - dns domain added for pptp
  - kde3 type in version added
  * bugfixes
  - crash at smartcard options widget fixed [kde4]
  - selector on authentication page fixed [kde4]
  - gui freeze eleminations [kde4]
  - username display on status fixed (openvpn) [kde4]
  - use remote network changing on profilenetworkgeneraloptions fixed [kde4]
  - replace custom bug report entry with homepage call entry [kde4]
  - profiletype on profilemanger fixed [kde4]
  - interface detection fixed [kde4]
  - racoon specific page moved to connection specific in profilemanger [kde4]
  - restoring last profile fixed [kde4]
  - echo mode on import certificate dialog fixed [kde4]
  - echo mode on psk options dialog fixed [kde4]
  - echo mode on cisco manually dialog fixed [kde4]
  - manageciscocert dialog fixed [kde4]
  - read profile data fixed (pcf file) [kde4]
  - crash on openening profilemanger fixed [kde4]
  - fixes regarding dns update
  - saving cisco nat mode fixed
* Wed Jul 29 2009 tittiatcoke@gmail.com
- update to svn1004178
  * several bugfixes
  * ask user password on each connect option added
* Tue Jul 28 2009 tittiatcoke@gmail.com
- update to svn1003701
  * replace all q3process and k3process with qt4/kde4 replacement
  * profiletype on profilemanger fixed
  * path to tail after change in profilemanger fixed
  * interface detection fixed
  * racoon specific page moved to connection specific in profilemanger
* Sat Jul 11 2009 tittiatcoke@gmail.com
- update to svn994994
  + further replacement of deprecated qt3 functions
* Mon Jun 22 2009 tittiatcoke@gmail.com
- update to svn985429
  + Fixes crashes when starting configuration/profile manager
  + Fixes double route add when disconnecting
* Sun May 31 2009 tittiatcoke@gmail.com
- update to svn976013
  + further usage of Qt4/KDE4 classes and dialogs
* Sun May 31 2009 dmueller@suse.de
- rename to kvpnc
* Fri May 29 2009 tittiatcoke@gmail.com
- update to svn974857
  + Further enhancements on the usage of KDE classes
* Fri May 29 2009 tittiatcoke@gmail.com
- Update to svn974436
* Wed May 27 2009 tittiatcoke@gmail.com
- Update to svn973723
  + Further changes regarding usage of KDE classes.
* Tue May 26 2009 tittiatcoke@gmail.com
- Update to svn 972862
  + Use KDE classes instead of Qt classes when possible
* Thu Apr 30 2009 tittiatcoke@gmail.com
- Update to svn961385
  * Update Copyrights
* Wed Apr 22 2009 tittiatcoke@gmail.com
- Update to svn957447
  + Fix mem leaks
  + Fix i18n
  + Fix coding style
* Mon Apr 20 2009 tittiatcoke@gmail.com
- Update to svn956814
* Sat Apr 18 2009 tittiatcoke@gmail.com
- Update to svn956279
* Mon Apr  6 2009 tittiatcoke@gmail.com
- Update to svn950358
  + Proof-reading
* Sun Apr  5 2009 tittiatcoke@gmail.com
- Update to svn 949371
  + Started working on proof-reading
* Fri Apr  3 2009 tittiatcoke@gmail.com
- Update to svn 948713
  + sshPathChanged slot fixed
* Tue Mar 31 2009 tittiatcoke@gmail.com
- Update to svn 947521
  + crash fixes
* Mon Mar 30 2009 tittiatcoke@gmail.com
- Update to svn 946998
  + rename to empty name fixed
  + openvpn import menu entry fixed
  + missing icons fixed
  + missing files on import fixed
  + size fixed
  + missing files on import fixed
  + profile data not right found on pcf import fixed
  + option for selecting open profilemanger after import added (pcf import)
  + slot disconnect fixed
  + dont show error msgbox on cancel
* Sun Mar 29 2009 tittiatcoke@gmail.com
- Update to svn 946544
  + code reformatted
  + pkcs11 token support for other than etoken added
  + memory leak fixes
  + compile fix
* Sat Mar 28 2009 tittiatcoke@gmail.com
- Update to svn 946031
  + pkcs11 parameters changed for openvpn >= 2.1rc-9
  + openvpn version detection improved
  + crash fix
* Fri Mar 27 2009 tittiatcoke@gmail.com
- Update to svn 945327
* Fri Mar 13 2009 tittiatcoke@gmail.com
- Update to svn 939034
  + Fixed: listing is not a boolean, but a list of
    data fields delivered, so listing=false is wrong
    (although recognized by KIO, but still wrong)
* Thu Mar  5 2009 tittiatwork@hotmail.cpm
- Update to SVN 935585
  - Moved to KDE:KDE4:Community repository
* Sun Feb 22 2009 tittiatwork@hotmail.com
- initial KDE4 package of version 1.0.cmake
* Tue Jan  8 2008 stbinner@suse.de
- update to 0.9.0: several bug fixes and minor new features
* Tue Oct 23 2007 stbinner@suse.de
- fix build with gcc 4.3
* Fri Jun  1 2007 coolo@suse.de
- use kde_post_install
* Wed May  2 2007 stbinner@suse.de
- update to 0.8.9: bug fixes and
  * fix for vpnc 0.4.0 which has changed udp option
  * openvpn import now copy cert files to kvpnc data dir if not
    absolute path is given
  * option for delay before executing command after connect added
  * tunnel device type selection for vpnc >= 0.4.0 added
  * authorization method added: pap (pptp)
* Mon Feb 19 2007 stbinner@suse.de
- update to version 0.8.8: for all bugfixes and minor enhancements
  see http://home.gna.org/kvpnc/en/changelog.html
* Wed Dec 13 2006 stbinner@suse.de
- update to version 0.8.7:
  * NT Domain name for authentication added (pptp)
  * support for missing replacedefaultroute at old pppd added
  * userdefinied mtu for cisco added
  * support for ca cert and user authentication (openvpn)
  * changed info for daemon programs will now shown directly after change
  * Japanese translation added
  * http proxy auth for openvpn added
* Sat Sep 30 2006 stbinner@suse.de
- update to version 0.8.6.1:
  * restoring default route at cisco connection fixed
  * typo fix for openvpn tunnel device type
  * comments are now removed from config lines on openvpn import
  * crash at rename fixed
  * pcf import fixed
  * resolv.conf restore problem fixed (vpnc)
  * vpnc config is now send via stdin
* Tue Sep 26 2006 stbinner@suse.de
- update to version 0.8.6:
  * pcf import now reads pcf files which contain ! at beginning
  * openvpn now controlled via management interface
  * dns names are now resolved by libresolv instead of qdns
  * network interface class use much less qprocess for better event
    handling and better speed
  * program and pid detection for given port added
  * kvpnc gives now a hint which program is using listening port
    if port bindung failed
  * support for xauth interactive added
  * openvpn pkcs11 support (thanks to Alon Bar-Lev)
  * dcop options added: doImportPcf, doImportOpenvpnConfig
  * command line parameters added: --openvpnimport, --ciscoimport
  * option for disabling ccp negotiation added
  * vpnc will now used in non interactive mode because reading
    from console is broken in vpnc
* Tue Jun 20 2006 dmueller@suse.de
- build parallel
* Tue May 30 2006 adrian@suse.de
- fix build for < 10.1
* Mon May 22 2006 stbinner@suse.de
- update to version 0.8.5.1
  * loading mppe module now handles other special case
* Thu May 18 2006 stbinner@suse.de
- update to version 0.8.5
  * vpnc script generation fixed
  * libcrypt detection fixed
  * vpnc output parsing fixed
  * option for peer timeout added
  * pcf import now uses peer timeout
  * debug output of kvpnc > 1 shows now the vpnc arguments
  * log file is now synchron written
  * copy action for debug output added
  * process handling improved
  * userdefinied packet size added (openvpn)
  * userdefinied packet size for fragmentation added (openvpn)
  * network interface handling improved
* Sun Apr  9 2006 stbinner@suse.de
- update to version 0.8.4
  * ipsec.conf and ipsec.secrets will no longer overwritten
  * back behavior in newprofile wizard fixed
  * aggressive mode fixed (freeswan)
  * psk for freeswan fixed
  * starting connection after setup fixed
  * resolv.conf will no longer changed if no nameserver is retrieved/entered (pptp)
  * additional network routes fixed
  * disabling kwallet fixed
  * crash at close on empty profile list fixed
  * openvpn hangs on connecting fixed
  * window size and position storing fixed
  * hide on close warning dialog fixed
  * directory mode for certificate path in new profile dialog fixed
  * tab sort order dialogs fixed
  * udp option in preferences dialog for openvpn fixed
  * tls auth in newprofile wizard fixed
  * path for p12 certificate at openvpn import fixed
  * displaying certificate entries in profile manager fixed
  * password dialog for openvpn fixed
  * push options for openvpn fixed
  * connection status check options for openvpn fixed
  * some fixes around newprofile wizard
  * vpnc connect script fixed if no resolconf is used
  * openvpn user authentication fixed
  * *.crt for filter added
  * openvpn now looks in cert path for certificates
  * option for disabling pfs added (freeswan)
  * verbose option for ipsec added
  * automatic detection for ipsec.* files added
  * automatic killing ipsec if not started from kvpnc at connect
  * tunnel ip now shown for pptp and openvpn
  * option for left and right next hop added (freeswan)
  * option for disabling opportunistic encryption added (freeswan)
  * patch for skip focus to password if username already cached (thanks to Tim Wootton) added
  * name will now checked if profile from wizard was imported
  * agressive mode for freeswan/openswan added ipsec.conf and ipsec.secrets will no longer
    overwritten
  * back behavior in newprofile wizard fixed
  * aggressive mode fixed (freeswan)
  * psk for freeswan fixed
  * starting connection after setup fixed
  * resolv.conf will no longer changed if no nameserver is retrieved/entered (pptp)
  * additional network routes fixed
  * disabling kwallet fixed
  * crash at close on empty profile list fixed
  * openvpn hangs on connecting fixed
  * window size and position storing fixed
  * hide on close warning dialog fixed
  * directory mode for certificate path in new profile dialog fixed
  * tab sort order dialogs fixed
  * udp option in preferences dialog for openvpn fixed
  * tls auth in newprofile wizard fixed
  * path for p12 certificate at openvpn import fixed
  * displaying certificate entries in profile manager fixed
  * password dialog for openvpn fixed
  * push options for openvpn fixed
  * connection status check options for openvpn fixed
  * some fixes around newprofile wizard
  * vpnc connect script fixed if no resolconf is used
  * openvpn user authentication fixed
  * *.crt for filter added
  * openvpn now looks in cert path for certificates
  * option for disabling pfs added (freeswan)
  * verbose option for ipsec added
  * automatic detection for ipsec.* files added
  * automatic killing ipsec if not started from kvpnc at connect
  * tunnel ip now shown for pptp and openvpn
  * option for left and right next hop added (freeswan)
  * option for disabling opportunistic encryption added (freeswan)
  * patch for skip focus to password if username already cached (thanks to Tim Wootton) added
  * name will now checked if profile from wizard was imported
  * agressive mode for freeswan/openswan added
* Mon Mar  6 2006 stbinner@suse.de
- update to version 0.8.3
  * info that process was killed is shown multiple times fixed
  * key shortcut menu entry fixed
  * more ui freezes eleminated
  * remote network storing fixed (pptp, OpenVPN)
  * crash at preferencesdialog after deleting profile in it fixed
  * retrieving username and password from enterpassworddialog fixed
  * output for connection status check fixed if userdefined ip address is used
  * wizard for creating new profile added
  * support for TLS remote host for openvpn added
  * support for pushed options (dns, domain) for openvpn added
  * ping IP address after connect (obsolete) removed
  * use userdefinied ip address for connection status check added
  * delay for auto reconnect added
  * patch for splitrules applied (thanks to Tilman Vogel)
  * auth retry after failed password for openvpn added
  * keep default route for pptp added
  * ike exchange mode for racoon added
  * option for dont save username added
  * openvpn config file import added
  * new dcop functions
  * doImportOpenvpnConfig
  * createNewProfileWithWizard
  * tls auth option for openvpn added
  * http proxy support for openvpn added
  * userdefinied ciphers for openvpn added
  * redirect gateway option for openvpn added
  * automatically adding ppp-compress-18 alias to /etc/modprobe.conf
  * automatically try to load ppp_mppe instead of ppp-compress-18
  * automatically detection of mppe style
  * toolinfo now collects info about pptp
  * option for debug level of pptp added
  * more tooltips added
  * information of deamons now shown in preferencesdialog
  * Swedish andbook added. Thanks to Daniel Nylander who has translate it.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  2 2006 stbinner@suse.de
- update to version 0.8.2.1
* Fri Dec  9 2005 stbinner@suse.de
- update to version 0.8.1
* Sun Nov 13 2005 stbinner@suse.de
- fix filelist
* Wed Jul  6 2005 cthiel@suse.de
- update to version 0.7.2
* Sun Jul  3 2005 dmueller@suse.de
- update to version 0.7.1
* Mon Feb 28 2005 adrian@suse.de
- update to version 0.6
  * OpenVPN support
  * PPTP support
* Mon Feb  7 2005 adrian@suse.de
- initial package of version 0.5.1
